"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/http.ts
var http_exports = {};
__export(http_exports, {
  fetchWithRetry: () => fetchWithRetry,
  graphqlFetchWithRetry: () => graphqlFetchWithRetry
});
module.exports = __toCommonJS(http_exports);

// src/retry.ts
async function retryWhenFailed(fn, maxRetries = 5, initialSleepTime = 1e3, stopOnError) {
  let attempt = 0;
  while (attempt < maxRetries) {
    try {
      return await fn();
    } catch (e) {
      if (typeof stopOnError === "function") {
        const error = e;
        if (stopOnError(error)) {
          throw error;
        }
      }
      attempt += 1;
      if (attempt >= maxRetries) {
        throw e;
      }
      const jitter = Math.random();
      const delay = 2 ** attempt * initialSleepTime * jitter;
      await new Promise((resolve) => setTimeout(resolve, delay));
    }
  }
  throw new Error("Retry failed");
}

// src/http/fetch-with-retry.ts
async function fetchWithRetry(input, init, maxRetries = 5, initialSleepTime = 3e3) {
  return retryWhenFailed(
    async () => {
      const response = await fetch(input, init);
      if (response.ok) {
        return response;
      }
      if (response.status < 500 && response.status !== 429 && response.status !== 408 && response.status !== 0) {
        return response;
      }
      throw new Error(`HTTP error! status: ${response.status} ${response.statusText}`);
    },
    maxRetries,
    initialSleepTime
  );
}

// src/http/graphql-fetch-with-retry.ts
async function graphqlFetchWithRetry(input, init, maxRetries = 5, initialSleepTime = 3e3) {
  return retryWhenFailed(
    async () => {
      const response = await fetchWithRetry(input, init);
      const json = await response.json();
      if (json.errors) {
        throw new Error(`GraphQL errors in response: ${json.errors.map((error) => error.message).join(", ")}`);
      }
      return json.data;
    },
    maxRetries,
    initialSleepTime
  );
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  fetchWithRetry,
  graphqlFetchWithRetry
});
//# sourceMappingURL=http.cjs.map